pub struct WeatheringCopper {
weather_state: WeatherState,
}Expand description
Composable helper for copper weathering/oxidation logic.
Add this as a field to block implementations that should support weathering.
In YourBlock::random_tick call WeatheringCopper::change_over_time
Fields
weather_state: WeatherStateImplementations
Sourceimpl WeatheringCopper
impl WeatheringCopper
Sourcepub const fn new(weather_state: WeatherState) -> Self
pub const fn new(weather_state: WeatherState) -> Self
Creates a new WeatheringCopper helper with the given oxidation stage.
Sourcepub fn change_over_time(
&self,
state: BlockStateId,
world: &Arc<World>,
pos: BlockPos,
)
pub fn change_over_time( &self, state: BlockStateId, world: &Arc<World>, pos: BlockPos, )
Advances the weathering state and replaces the block, with a 5.7% chance.
Vanilla: [ChangeOverTimeBlock.changeOverTime]
Sourcefn get_next_state(
&self,
state: BlockStateId,
world: &Arc<World>,
pos: BlockPos,
) -> Option<BlockStateId>
fn get_next_state( &self, state: BlockStateId, world: &Arc<World>, pos: BlockPos, ) -> Option<BlockStateId>
Checks the neighbors and calculates the next BlockStateId for the weathering copper.
- Scan Manhattan distance 4 for copper neighbors
- If any younger neighbor exists, abort
- Probability = ((older+1)/(older+same+1))² ×
chance_modifier - On success, advance to next oxidation stage preserving block properties
Vanilla: ChangeOverTimeBlock.getNextState
fn get_chance_modifier(&self) -> f32